@@ -1,28 +1,22 @@
 package Lingua::PTD;
 
-use 5.010;
-
 use parent 'Exporter';
 our @EXPORT = 'toentry';
 our @EXPORT_OK = qw/bws ucts/;
 use warnings;
 use strict;
 
-use utf8;
 use POSIX qw/setlocale/;
+setlocale(&POSIX::LC_CTYPE, "en_US");
 use locale;
 
-BEGIN {
-    setlocale(&POSIX::LC_CTYPE, "pt_PT");
-}
-
 use Time::HiRes;
 use Lingua::PTD::Dumper;
 use Lingua::PTD::BzDmp;
 use Lingua::PTD::XzDmp;
 use Lingua::PTD::SQLite;
 
-our $VERSION = '1.04_04';
+our $VERSION = '1.01';
 
 =encoding UTF-8
 
